==> mobcapture-0.1.2%2B1.21.5-sources.jar: de/kaama/mobcapture/datagen/EnchantmentGenerator.java <==
package de.kaama.mobcapture.datagen;

//? if >=1.21 {

import de.kaama.mobcapture.MobCaptureMod;
import de.kaama.mobcapture.enchantment.effect.CapturingEnchantmentEffect;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricDynamicRegistryProvider;
import net.fabricmc.fabric.api.resource.conditions.v1.ResourceCondition;
import net.minecraft.class_1887;
import net.minecraft.class_3489;
import net.minecraft.class_5321;
import net.minecraft.class_7225;
import net.minecraft.class_7924;
import net.minecraft.class_9274;
import net.minecraft.class_9701;
import net.minecraft.class_9703;
import net.minecraft.class_9704;
import java.util.concurrent.CompletableFuture;

public class EnchantmentGenerator extends FabricDynamicRegistryProvider {
    public EnchantmentGenerator(FabricDataOutput output, CompletableFuture<class_7225.class_7874> registriesFuture) {
        super(output, registriesFuture);
    }

    @Override
    protected void configure(class_7225.class_7874 registries, Entries entries) {

        // This block is active for Minecraft versions 1.21.2 and above.
        // It uses 'registries.getOrThrow(RegistryKeys.ITEM)'.
        /*? if >=1.21.2 {*/
        register(entries, MobCaptureMod.CAPTURING_ENCHANTMENT_KEY, class_1887.method_60030(
                        class_1887.method_58443(
                                registries.method_46762(class_7924.field_41197).method_46735(class_3489.field_42611),
                                registries.method_46762(class_7924.field_41197).method_46735(class_3489.field_42611),
                                10,
                                3,
                                class_1887.method_58441(1, 10),
                                class_1887.method_58441(1, 15),
                                5,
                                class_9274.field_49219
                        ))
                .method_60063(
                        class_9701.field_51665,
                        class_9703.field_51683,
                        class_9703.field_51685,
                        new CapturingEnchantmentEffect(class_9704.method_60187(0.05f, 0.05f))
                )
        );
        /*?}*/
        // This block is active for Minecraft versions 1.21 and 1.21.1 only.
        // It uses 'registries.getWrapperOrThrow(RegistryKeys.ITEM)'.
        /*? if <1.21.2 {*/
        /*register(entries, MobCaptureMod.CAPTURING_ENCHANTMENT_KEY, Enchantment.builder(
                        Enchantment.definition(
                                registries.getWrapperOrThrow(RegistryKeys.ITEM).getOrThrow(ItemTags.SWORDS),
                                registries.getWrapperOrThrow(RegistryKeys.ITEM).getOrThrow(ItemTags.SWORDS),
                                10,
                                3,
                                Enchantment.leveledCost(1, 10),
                                Enchantment.leveledCost(1, 15),
                                5,
                                AttributeModifierSlot.HAND
                        ))
                .addEffect(
                        EnchantmentEffectComponentTypes.POST_ATTACK,
                        EnchantmentEffectTarget.ATTACKER,
                        EnchantmentEffectTarget.VICTIM,
                        new CapturingEnchantmentEffect(EnchantmentLevelBasedValue.linear(0.05f, 0.05f))
                )
        );
        *//*?}*/
    }

    private void register(Entries entries, class_5321<class_1887> key, class_1887.class_9700 builder, ResourceCondition... resourceConditions) {
        entries.add(key, builder.method_60060(key.method_29177()), resourceConditions);
    }

    @Override
    public String method_10321() {
        return MobCaptureMod.MOD_ID + " Enchantment Generator";
    }
}
//?}

==> mobcapture-0.1.3%2B1.21-sources.jar: de/kaama/mobcapture/datagen/EnchantmentGenerator.java <==
package de.kaama.mobcapture.datagen;

//? if >=1.21 {

import de.kaama.mobcapture.MobCaptureMod;
import de.kaama.mobcapture.enchantment.effect.CapturingEnchantmentEffect;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricDynamicRegistryProvider;
import net.fabricmc.fabric.api.resource.conditions.v1.ResourceCondition;
import net.minecraft.class_1887;
import net.minecraft.class_3489;
import net.minecraft.class_5321;
import net.minecraft.class_7225;
import net.minecraft.class_7924;
import net.minecraft.class_9274;
import net.minecraft.class_9701;
import net.minecraft.class_9703;
import net.minecraft.class_9704;
import java.util.concurrent.CompletableFuture;

public class EnchantmentGenerator extends FabricDynamicRegistryProvider {
    public EnchantmentGenerator(FabricDataOutput output, CompletableFuture<class_7225.class_7874> registriesFuture) {
        super(output, registriesFuture);
    }

    @Override
    protected void configure(class_7225.class_7874 registries, Entries entries) {

        // This block is active for Minecraft versions 1.21.2 and above.
        // It uses 'registries.getOrThrow(RegistryKeys.ITEM)'.
        /*? if >=1.21.2 {*/
        /*register(entries, MobCaptureMod.CAPTURING, Enchantment.builder(
                        Enchantment.definition(
                                registries.getOrThrow(RegistryKeys.ITEM).getOrThrow(ItemTags.SWORDS),
                                registries.getOrThrow(RegistryKeys.ITEM).getOrThrow(ItemTags.SWORDS),
                                10,
                                3,
                                Enchantment.leveledCost(1, 10),
                                Enchantment.leveledCost(1, 15),
                                5,
                                AttributeModifierSlot.HAND
                        ))
                .addEffect(
                        EnchantmentEffectComponentTypes.POST_ATTACK,
                        EnchantmentEffectTarget.ATTACKER,
                        EnchantmentEffectTarget.VICTIM,
                        new CapturingEnchantmentEffect(EnchantmentLevelBasedValue.linear(0.05f, 0.05f))
                )
        );
        *//*?}*/
        // This block is active for Minecraft versions 1.21 and 1.21.1 only.
        // It uses 'registries.getWrapperOrThrow(RegistryKeys.ITEM)'.
        /*? if <1.21.2 {*/
        register(entries, MobCaptureMod.CAPTURING, class_1887.method_60030(
                        class_1887.method_58443(
                                registries.method_46762(class_7924.field_41197).method_46735(class_3489.field_42611),
                                registries.method_46762(class_7924.field_41197).method_46735(class_3489.field_42611),
                                10,
                                3,
                                class_1887.method_58441(1, 10),
                                class_1887.method_58441(1, 15),
                                5,
                                class_9274.field_49219
                        ))
                .method_60063(
                        class_9701.field_51665,
                        class_9703.field_51683,
                        class_9703.field_51685,
                        new CapturingEnchantmentEffect(class_9704.method_60187(0.05f, 0.05f))
                )
        );
        /*?}*/
    }

    private void register(Entries entries, class_5321<class_1887> key, class_1887.class_9700 builder, ResourceCondition... resourceConditions) {
        entries.add(key, builder.method_60060(key.method_29177()), resourceConditions);
    }

    @Override
    public String method_10321() {
        return MobCaptureMod.MOD_ID + " Enchantment Generator";
    }
}
//?}
